---
title: <span class="badge object-type-scalar"></span> PercentUnit
---
# <span class="badge object-type-scalar"></span> PercentUnit

Percent (0.0-1.0)

## Definition

```python
# Percent (0.0-1.0)
PercentUnit: typing.Literal["percentunit"] = "percentunit"
```
